Class: Google::Shopping::Merchant::Notifications::V1::GetNotificationSubscriptionHealthMetricsRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/shopping/merchant/notifications/v1/notificationsapi.rb

Overview

Request for notification subscription health metrics.

Instance Attribute Summary collapse

Instance Attribute Details

#name::String

Returns Required. The name of the notification subscription for which metrics are retrieved. Format: accounts/{account}/notificationsubscriptions/{notification_subscription}.

Returns:

  • (::String)

    Required. The name of the notification subscription for which metrics are retrieved. Format: accounts/{account}/notificationsubscriptions/{notification_subscription}



151
152
153
154
# File 'proto_docs/google/shopping/merchant/notifications/v1/notificationsapi.rb', line 151

class GetNotificationSubscriptionHealthMetricsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end