Class: Google::Shopping::Merchant::Notifications::V1::NotificationSubscriptionHealthMetrics

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/shopping/merchant/notifications/v1/notificationsapi.rb

Overview

Represents a notification subscription health metrics.

Instance Attribute Summary collapse

Instance Attribute Details

#acknowledged_messages_count::Integer

Returns The number of retained acknowledged messages for the last 24 hours.

Returns:

  • (::Integer)

    The number of retained acknowledged messages for the last 24 hours



176
177
178
179
# File 'proto_docs/google/shopping/merchant/notifications/v1/notificationsapi.rb', line 176

class NotificationSubscriptionHealthMetrics
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#name::String (readonly)

Returns Output only. Identifier. The name of the notification configuration. Generated by the Content API upon creation of a new NotificationSubscription. The account represents the merchant ID of the merchant that owns the configuration.

Returns:

  • (::String)

    Output only. Identifier. The name of the notification configuration. Generated by the Content API upon creation of a new NotificationSubscription. The account represents the merchant ID of the merchant that owns the configuration.



176
177
178
179
# File 'proto_docs/google/shopping/merchant/notifications/v1/notificationsapi.rb', line 176

class NotificationSubscriptionHealthMetrics
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#oldest_unacknowledged_message_waiting_time::Integer

Returns The time since the oldest unacknowledged message was sent in seconds.

Returns:

  • (::Integer)

    The time since the oldest unacknowledged message was sent in seconds



176
177
178
179
# File 'proto_docs/google/shopping/merchant/notifications/v1/notificationsapi.rb', line 176

class NotificationSubscriptionHealthMetrics
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#undelivered_messages_count::Integer

Returns The number of unacknowledged messages for the last 7 days, we will attempt to re-deliver the unacknowledged message later and once successfully delivered it will not be counted within unacknowledged messages (the number of unacknowledged messages should gradually decrease to zero once the issue is fixed).

Returns:

  • (::Integer)

    The number of unacknowledged messages for the last 7 days, we will attempt to re-deliver the unacknowledged message later and once successfully delivered it will not be counted within unacknowledged messages (the number of unacknowledged messages should gradually decrease to zero once the issue is fixed).



176
177
178
179
# File 'proto_docs/google/shopping/merchant/notifications/v1/notificationsapi.rb', line 176

class NotificationSubscriptionHealthMetrics
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end